The ‘download’ views — CubicWeb 3.13.2

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Web side development »
- The View system »

# The ‘download’ views

## Specific views for entities adapting to IDownloadable

## Components

class `cubicweb.web.views.idownloadable.` `DownloadBox`(*args, **kwargs)
  add download box

## Download views

class `cubicweb.web.views.idownloadable.` `DownloadView`(req=None, rset=None, **kwargs)

  download view

  this view is replacing the deprecated ‘download’ controller and allow downloading of entities providing the necessary interface

class `cubicweb.web.views.idownloadable.` `DownloadLinkView`(req=None, rset=None, **kwargs)
  view displaying a link to download the file

class `cubicweb.web.views.idownloadable.` `IDownloadablePrimaryView`(req=None, rset=None, **kwargs)

class `cubicweb.web.views.idownloadable.` `IDownloadableLineView`(req=None, rset=None, **kwargs)

## Embedded views

class `cubicweb.web.views.idownloadable.` `ImageView`(req=None, rset=None, **kwargs)
  image embedded view

class `cubicweb.web.views.idownloadable.` `EHTMLView`(req=None, rset=None, **kwargs)
  html embedded view

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Web side development »
- The View system »